@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -28,11 +28,18 @@ class CategoryTypeComboBox : public QComboBox
 {
     Q_OBJECT
 public:
-    explicit CategoryTypeComboBox(bool customType, QWidget *parent = Q_NULLPTR);
+    explicit CategoryTypeComboBox(bool customType, QWidget *parent = nullptr);
     ~CategoryTypeComboBox();
 
     LoggingCategory::LoggingType type() const;
     void setType(LoggingCategory::LoggingType type);
+    bool loggingCategoryIsNotDefault() const;
+    void setDefaultCategories(const LoggingCategory::LoggingType &defaultCategories);
+    LoggingCategory::LoggingType defaultCategories() const;
+
+    void restoreToDefault();
+private:
+    LoggingCategory::LoggingType mDefaultCategories = LoggingCategory::Info;
 };
 
 #endif // CATEGORYTYPECOMBOBOX_H
