@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -24,15 +24,20 @@
 #include <QVector>
 #include <QString>
 #include <QObject>
+#include <QDebug>
 struct KdeLoggingCategory {
     KdeLoggingCategory();
     typedef QVector<KdeLoggingCategory> List;
     bool operator ==(const KdeLoggingCategory &other) const;
+    bool operator !=(const KdeLoggingCategory &other) const;
     bool isValid() const;
 
     QString description;
     QString logName;
+    //Use enum ?
+    QString defaultCategory;
 };
+QDebug operator<<(QDebug debug, const KdeLoggingCategory &cat);
 Q_DECLARE_TYPEINFO(KdeLoggingCategory, Q_MOVABLE_TYPE);
 Q_DECLARE_METATYPE(KdeLoggingCategory)
 
